import re
import os
import json


def make_brython_modules(vfs):
    # save in brython_modules.js
    with open("brython_modules.js", "w", encoding="utf-8") as out:
        out.write("__BRYTHON__.use_VFS = true\n__BRYTHON__.VFS = ")
        json.dump(vfs, out)
    # save in brython_modules.js
    with open("brython_modules.log.txt", "w", encoding="utf-8") as out:
        for key in sorted(list(vfs.keys())):
            line = "%s%s(%s)" % (key, vfs[key][0],
                                 'module' if len(vfs[key]) == 3 else 'file')
            out.write("====%s start====\n" % line)
            out.write(vfs[key][1])
            out.write("====%s end====\n\n" % line)


def remove_useless_newlines(src):
    return re.sub('\n(\s+\n)+', '\n\n', src)


def filter_out_docstring(content):
    comment = 0
    triple_in_function = 0
    for line in content.split('\n'):
        if re.match('\s*#', line):
            continue
        if re.match('\s*"{3}.*"{3}', line):
            continue
        if re.match('.*?\S+.*?"{3}', line) and triple_in_function == 0:
            triple_in_function = 1
        if re.match('\s*r?"{3}', line) and comment == 0:
            if triple_in_function == 1:
                triple_in_function == 0
            else:
                comment = 1
                continue
        if re.match('\s*"{3}\s*$', line) and comment == 1:
            comment = 0
            continue
        if comment == 0:
            yield line


def walk(folder):
    for f in os.scandir(folder):
        if f.is_file() and f.path.endswith('.py'):
            yield f
        elif f.is_dir():
            yield from walk(f.path)



import os

import brython_pack.utils as utils


class Pack:

    def __init__(self):
        self.bob = {}
        self.dependencies = {}
        self.modules = set()
        self.base_path = None

    def work(self, path_file):
        self.base_path = os.path.dirname(path_file)
        if os.path.isfile(path_file):
            self.__process(path_file)
        else:
            self.__process_dir(path_file)

    def __process_dir(self, path):
        for f in utils.walk(path):
            self.__process(f.path)

    def __process(self, afile):
        module = self.__extract_module_name(afile)
        with open(afile, 'r') as pyf:
            content = '\n'.join(utils.filter_out_docstring(pyf.read()))
            if '__init__' in module:
                module = module.replace('.__init__', '')
                self.bob[module] = ['.py', content, 1]
            else:
                self.bob[module] = ['.py', content]

    def __extract_module_name(self, afile):
        if self.base_path:
            module = afile[len(self.base_path)+1:]
        else:
            module = afile
        module = module.replace('/', '.')
        module = module[:-3]
        return module



import sys


from brython_pack._version import __version__
from brython_pack.stdlib import StdLib
from brython_pack.pack import Pack
from brython_pack.utils import make_brython_modules


HELP_TEXT = """version: %s
usage:

    bp brython_stdlib.js requirements.txt your packages and file list

where:

    brython_stdlib.js: should be the accessible path to the lib file.
    requirements.txt: is the hard coded and manually worked out dependencies
                      on brython_stdlib.txt. Not the pip requirements.txt.
    your packages file list: could be given as space separated arguments.

examples:

    bp dependencies/brython_stdlib.js requirements.txt pyecharts editor.py
""" % __version__


def main():
    if len(sys.argv) == 1:
        show_help()

    if sys.argv[1] in ['-h', '--help']:
        show_help()

    if len(sys.argv) < 4:
        print("Nothing to do")
        show_help()

    process(sys.argv[1], sys.argv[2], sys.argv[3:])


def process(lib_file, req_file, packages_and_files):
    # real work:
    std_deps = cherry_pick_lib(lib_file, req_file)
    pack = pack_up(packages_and_files)
    # merge all
    std_deps.update(pack)
    make_brython_modules(std_deps)


def cherry_pick_lib(lib_file, req_file):
    stdlib = StdLib(lib_file)
    with open(req_file, 'r') as f:
        deps = [x for x in f.read().split('\n') if x]
    std_deps = stdlib.install_requires(deps)
    return std_deps


def pack_up(packages_and_files):
    pack = Pack()
    for path in packages_and_files:
        pack.work(path)
    return pack.bob


def show_help():
    print(HELP_TEXT)
    sys.exit(0)


if __name__ == '__main__':
    main()



import json

import brython_pack.utils as utils


class StdLib:
    def __init__(self, lib_path):
        self.stdlib = None
        with open(lib_path, encoding="utf-8") as fobj:
            modules = fobj.read()
            modules = modules[modules.find('{'):]
            self.stdlib = json.loads(modules)

    def install_requires(self, modules):
        """Build brython_modules.js from the list of modules needed by the
        application.
        """
        vfs = {}
        for module in modules:
            if module in self.stdlib:
                vfs[module] = self.stdlib[module]
                src = vfs[module][1]
                if vfs[module][0] == '.py':
                    src = '\n'.join(list(utils.filter_out_docstring(src)))
                src = utils.remove_useless_newlines(src)
                vfs[module][1] = src
            else:
                print("%s is not found" % module)
        return vfs



# Template by setupmobans
import os
import codecs
from shutil import rmtree
from setuptools import setup, find_packages, Command
import sys
PY2 = sys.version_info[0] == 2
PY26 = PY2 and sys.version_info[1] < 7

NAME = 'brython-pack'
AUTHOR = 'C.W.'
VERSION = '0.0.1'
EMAIL = 'wangc_2011@hotmail.com'
LICENSE = 'MIT'
ENTRY_POINTS = {
    'console_scripts': [
        'bp = brython_pack.main:main'
    ]
}
DESCRIPTION = (
    'packages your Python packages/files into a brython_modules.js' +
    ''
)
URL = 'https://github.com/chfw/brython-pack'
DOWNLOAD_URL = '%s/archive/0.0.1.tar.gz' % URL
FILES = ['README.rst',  'CHANGELOG.rst']
KEYWORDS = [
    'python'
]

CLASSIFIERS = [
    'Topic :: Office/Business',
    'Topic :: Utilities',
    'Topic :: Software Development :: Libraries',
    'Programming Language :: Python',
    'Intended Audience :: Developers',
    'Programming Language :: Python :: 2.6',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3.3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
]

INSTALL_REQUIRES = [
]


PACKAGES = find_packages(exclude=['ez_setup', 'examples', 'tests'])
EXTRAS_REQUIRE = {}
PUBLISH_COMMAND = '{0} setup.py sdist bdist_wheel upload -r pypi'.format(
    sys.executable)
GS_COMMAND = ('gs brython-pack v0.0.1 ' +
              "Find 0.0.1 in changelog for more details")
here = os.path.abspath(os.path.dirname(__file__))


class PublishCommand(Command):
    """Support setup.py upload."""

    description = 'Build and publish the package on github and pypi'
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print('\033[1m{0}\033[0m'.format(s))

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status('Removing previous builds…')
            rmtree(os.path.join(here, 'dist'))
        except OSError:
            pass

        self.status('Building Source and Wheel (universal) distribution…')
        if os.system(GS_COMMAND) == 0:
            os.system(PUBLISH_COMMAND)

        sys.exit()


def read_files(*files):
    """Read files into setup"""
    text = ""
    for single_file in files:
        content = read(single_file)
        text = text + content + "\n"
    return text


def read(afile):
    """Read a file into setup"""
    with codecs.open(afile, 'r', 'utf-8') as opened_file:
        content = filter_out_test_code(opened_file)
        content = "".join(list(content))
        return content


def filter_out_test_code(file_handle):
    found_test_code = False
    for line in file_handle.readlines():
        if line.startswith('.. testcode:'):
            found_test_code = True
            continue
        if found_test_code is True:
            if line.startswith('  '):
                continue
            else:
                empty_line = line.strip()
                if len(empty_line) == 0:
                    continue
                else:
                    found_test_code = False
                    yield line
        else:
            for keyword in ['|version|', '|today|']:
                if keyword in line:
                    break
            else:
                yield line


if __name__ == '__main__':
    setup(
        name=NAME,
        author=AUTHOR,
        version=VERSION,
        author_email=EMAIL,
        description=DESCRIPTION,
        url=URL,
        download_url=DOWNLOAD_URL,
        long_description=read_files(*FILES),
        license=LICENSE,
        keywords=KEYWORDS,
        extras_require=EXTRAS_REQUIRE,
        tests_require=['nose'],
        install_requires=INSTALL_REQUIRES,
        packages=PACKAGES,
        include_package_data=True,
        zip_safe=False,
        entry_points=ENTRY_POINTS,
        classifiers=CLASSIFIERS,
        setup_requires=['gease'],
        cmdclass={
            'publish': PublishCommand,
        }
    )
